<?php
/**
 * @package   FL Yandex Zen Plugin
 * @author    Дмитрий Васюков http://fictionlabs.ru
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

defined('_JEXEC') or die;

class FLYandexZenCoreZoo extends FLYandexZenCore {

	// Get COM_ZOO Content

	public function getContent()
	{
		// make sure ZOO exist
		jimport('joomla.filesystem.file');
		if (!JFile::exists(JPATH_ADMINISTRATOR.'/components/com_zoo/config.php')
				|| !JComponentHelper::getComponent('com_zoo', true)->enabled) {
			return;
		}

		// load zoo config
		require_once (JPATH_ADMINISTRATOR.'/components/com_zoo/config.php');

		// check if Zoo > 2.4 is loaded
		if (!class_exists('App')) {
			return;
		}

		// get the ZOO App instance
		$zoo = App::getInstance('zoo');

		// register plugin path
		if ($path = $zoo->path->path('root:plugins/ajax/flyandexzen/')) {
			$zoo->path->register($path, 'flyandexzen');
		}

		$result 	= array();
		$items 		= $this->getItems();

		$this->params->set('order', array('_itemcreated', '_reversed'));

		if (!empty($items)) {
			foreach ($items as $key => $item) {
				$renderer 	= $zoo->renderer->create('item');
				$date 	  	= new JDate($item->created);

				$renderer->addPath(array($zoo->path->path('component.site:'), dirname(dirname(__FILE__))));
				$renderer->checkPositions('item.default', $item);

				$content 	= $renderer->renderPosition('content');
				$image 		= $this->getImage($renderer->getPositionElements('image'));
				$categories = $renderer->getPositionElements('categories')[0]->render();
				$categories =  array_map('trim', explode(',', $categories));

				if (!empty($image)) {
					$content = $this->getImageLayout($image[0], $item->name).$content;
				}

				$result[] = array(
					'title' 		=> htmlspecialchars($item->name),
					'images' 		=> $this->getImagesFromHtml($content),
					'video'  		=> $this->getVideoFromHtml($content),
					'categories'    => $this->getCategories($categories),
					'link' 			=> JRoute::_($zoo->route->item($item, false), false, $this->ssl),
					'date' 			=> $date->toRFC822(true),
					'author' 		=> $this->getAuthor($item->created_by),
					'content' 		=> $this->prepareContent($content),
				);
			}
		}

		return $result;
	}

	// Get Zoo Items

	public function getItems()
	{	
		$zoo 			= App::getInstance('zoo');
		$options 		= $this->params->get('zoo_options');
		$order 			= 'created DESC';
		$applications 	= isset($options->zoo_apps) ? $options->zoo_apps : array();
		$types 			= isset($options->zoo_types) ? $options->zoo_types : array();
		$limit 			= isset($options->zoo_count) ? (int) $options->zoo_count : 500;
		$conditions     = array();

		// Only Published
		$conditions[] = 'state = 1';

		if ($applications) {
			$conditions[] = "application_id IN (".implode(',', $applications).")";
		}

		if ($types) {
			$conditions[] = "type IN ('".implode('\',\'', $types)."')";
		}

		if (!empty($conditions)) {
			$conditions = implode(' AND ', $conditions);
		}
		
        $result = $zoo->table->item->all(compact('conditions', 'order', 'limit'));

        return $result;
	}

	// Get Images From Content

	public function getImage($elements = array())
	{	
		$image = array();

		if (!empty($elements)) {
			$element 	= $elements[0];
			$title 		= $this->clearText($element->getItem()->name);
			$imageData	= $element->data();

            if ($element->config->type == 'image') {
                $image[] = $this->clearText(JURI::root() . str_replace('\\', '/', $imageData['file']));
            }

            if ($element->config->type == 'jbimage' || $element->config->type == 'jbgalleryimage') {
            	$row = $imageData[0];

            	
               
                if (isset($row['file']) && $row['file']) {
                    $image[] = $this->clearText(JURI::root() . str_replace('\\', '/', $row['file']));
                }
            }

            if ($element->config->type == 'jbgallery') {
            	$path = JPATH_ROOT . '/' . trim($element->config->directory, '/'). '/' . trim($imageData['value'], '/');

            	$files = JFolder::files($path, '.', false, true, array('.svn', 'CVS', '.DS_Store'));
		        $files = array_filter(
		            $files, create_function('$file', 'return preg_match("#(\.bmp|\.gif|\.jpg|\.jpeg|\.png)$#i", $file);')
		        );

		        $file = $files[0];

                $image[] = JURI::root().$this->getImageRelativeUrl($file);
        	}

            if (!empty($image)) {
            	return $image; 
            }
		}

		return $image; 
	}
}